@@ -1,5 +1,5 @@
 /* This file is part of KNemo
-   Copyright (C) 2009 John Stamp <jstamp@users.sourceforge.net>
+   Copyright (C) 2009, 2010 John Stamp <jstamp@users.sourceforge.net>
 
 
    KNemo is free software; you can redistribute it and/or modify
@@ -33,6 +33,7 @@
 #include <KSharedConfig>
 #include <KSharedConfigPtr>
 #include <KStandardDirs>
+#include "data.h"
 #include "utils.h"
 
 #ifdef __linux__
@@ -299,13 +300,13 @@ QFont setIconFont( const QString& text, const QFont& font, int iconWidth )
 double validatePoll( double val )
 {
     int siz = sizeof(pollIntervals)/sizeof(double);
-    for ( int i = 1; i < siz; i++ )
+    for ( int i = 0; i < siz; i++ )
     {
-        if ( val < pollIntervals[i] )
+        if ( val <= pollIntervals[i] )
         {
-            val = pollIntervals[i-1];
+            val = pollIntervals[i];
             return val;
         }
     }
-    return 1.0;
+    return GeneralSettings().pollInterval;
 }
